# -*- coding: UTF-8 -*-
import sys, os, re
from sys import argv

class SceneryOrganizer:
    def __init__(self):
        self.xp_path = self.get_path()
        self.airport_list   = []
        self.library_list   = []
        self.mesh_list      = []
        self.global_list    = []
        self.undefined_list = []
        self.counter        = 0
        
    def get_path(self):
        for index, arg in enumerate(sys.argv):
            if arg == "-d":
                return sys.argv[int(index) + 1]
            
    def get_scenery_list(self):
        for name in os.listdir(self.xp_path):
            if os.path.isdir(os.path.join(self.xp_path, name)):
                print(name + " é livraria" if self.is_library(name) else name + " não é livraria")
                self.counter += 1
        return ("There are {} folders here".format(self.counter))
    
    def is_library(self, scenery):
        regex = r"library"
        return re.finditer(regex, scenery, re.IGNORECASE)
        

scenery = SceneryOrganizer()

print(scenery.get_scenery_list())

# if os.path.exists(correct_dir):
#     os.chdir(correct_dir)
#     for directories in os.listdir(os.getcwd()):
#         print(directories if directories != "." else "")


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="xp-scenery-organizer",
    packages= ["xp-scenery-organizer"],
    license="CC BY-NC 4.0",
    version="0.0.1",
    author="João Bragança",
    author_email="jvbragancaa@gmail.com",
    description="A small package to organizer the X-plane's scenery_packs.ini file",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jvbraganca/xp-scenery-organizer",
    download_url = "https://github.com/jvbraganca/xp-scenery-organizer/archive/v0.tar.gz",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: Free for non-commercial use",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)